import { Easing } from "react-native";
import React from "react";
import ModalLayerAnimated from "./ModalLayerAnimated";
export default class ModalLayerController {
    constructor(key, options) {
        this.key = key;
        this.options = options;
        this.didHide = () => { };
        this.didShow = () => { };
        this.onShow = () => { };
        this.onHide = () => { };
        this.onLoad = () => { };
    }
    getComponent(...args) {
        const component = this.options.component;
        let content = typeof component === 'function' ? (component(...args)) : component;
        const beforeRef = content.ref;
        content = React.cloneElement(content, {
            ref: ref => {
                if (ref) {
                    if (ref.wrappedInstance)
                        ref.wrappedInstance.layer = this; // modalLayerRef;
                    else
                        ref.layer = this; // modalLayerRef;
                    if (beforeRef)
                        beforeRef(ref);
                }
            }
        });
        return content;
    }
    show(...args) {
        const modalLayerRef = this.modalLayerRef;
        if (!modalLayerRef)
            return setTimeout(() => this.show(...args), 10);
        const { component, boxStyle, act = ModalLayerAnimated.SCALE, hideEasing, showEasing = Easing.elastic(1), showDuration = 400, hideDuration = 200 } = this.options;
        modalLayerRef.hideEasing = hideEasing;
        modalLayerRef.showEasing = showEasing;
        modalLayerRef.showDuration = showDuration;
        modalLayerRef.hideDuration = hideDuration;
        modalLayerRef.show({
            component: this.getComponent(...args),
            boxStyle,
            act
        }, this.options.width).then(() => this.didShow());
        this.onShow();
    }
    preload(...args) {
        if (this.modalLayerRef)
            this.modalLayerRef.preload(this.getComponent(...args), () => this.onLoad());
        else
            setTimeout(() => this.preload(...args), 10);
    }
    setOptions(options) {
        this.options = { ...this.options, ...options };
    }
    hide() {
        this.onHide();
        this.modalLayerRef.hide().then(() => this.didHide());
    }
    backHandle(e) {
        const { backHandle } = this.options;
        if (!(backHandle && backHandle(e))) {
            this.hide();
        }
    }
}
