import React, { Component } from "react";
import ModalLayer from "./ModalLayer";
import ModalLayerController from "./ModalLayerController";
import _ from "lodash";
export default class ModalLayerFactory {
    static create(elem) {
        if (!this.self) {
            console.error("ModalLayers not loaded");
            return null;
        }
        let options;
        if (elem.prototype instanceof Component)
            options = {
                component: (props) => React.createElement(elem, props),
                ...elem.modalLayerOptions
            };
        else
            options = elem;
        const key = options.key || 'layer_' + (this.index++);
        const oldLayer = this.getLayer(key);
        if (oldLayer)
            return oldLayer;
        const modalLayerController = new ModalLayerController(key, options);
        const { zIndex = 0 } = options;
        const modalLayer = <ModalLayer key={key} zIndex={zIndex} ref={modalLayerRef => {
            if (modalLayerRef) {
                modalLayerController.modalLayerRef = modalLayerRef;
                modalLayerRef.mlc = modalLayerController;
                modalLayerRef.mlf = this;
            }
        }} shadePress={options.shadePress} shade={options.shade}/>;
        this.self.addModalLayer(modalLayer);
        this.modalLayerControllers.add(modalLayerController);
        return modalLayerController;
    }
    static getLayer(key) {
        let layer = null;
        this.modalLayerControllers.forEach(ml => {
            if (ml.key === key) {
                layer = ml;
            }
        });
        return layer;
    }
    static delete(mlc) {
        const self = this.self;
        if (mlc) {
            if (_.isArray(mlc)) {
                _(mlc).forEach((ad) => {
                    this.delete(ad);
                });
                return;
            }
            this.modalLayerControllers.delete(mlc);
            self.removeModalLayer(mlc.key);
        }
        else {
            self.modalLayers = [];
            self.setState({
                modalLayers: []
            });
            this.modalLayerControllers.clear();
        }
    }
    static hideAll() {
        this.forEach(mlc => {
            mlc.hide();
        });
    }
    static forEach(func) {
        this.modalLayerControllers.forEach(func);
    }
    static back() {
        let mdr;
        this.forEach(mlc => {
            if (mlc.modalLayerRef.state.isShow) {
                mdr = mlc;
            }
        });
        if (mdr) {
            mdr.backHandle();
            return true;
        }
        else
            return false;
    }
    static setModalLayersRef(mlsRef) {
        this.self = mlsRef;
    }
    static setElevation(elevation) {
        this.self.setElevation(elevation);
    }
}
ModalLayerFactory.index = 0;
ModalLayerFactory.modalLayerControllers = new Set();
